@@ -5,8 +5,9 @@ use version 0.77;
 use Mojo::Util 'dumper';
 use Sentry::Client;
 use Sentry::Hub;
+use Sentry::Logger 'logger';
 
-our $VERSION = version->declare('v1.0.1');
+our $VERSION = version->declare('v1.0.2');
 
 sub _call_on_hub ($method, @args) {
   my $hub = Sentry::Hub->get_current_hub();
@@ -35,6 +36,8 @@ sub init ($package, $options = {}) {
   $options->{_metadata}{sdk}
     = { name => 'sentry.perl', packages => [], version => $VERSION };
 
+  logger->active_contexts(['.*']) if $options->{debug};
+
   _init_and_bind($options);
 }
 
@@ -132,6 +135,10 @@ Enables your custom integration. Optional.
 
 This can be used to disable integrations that are added by default. When set to a falsy value, no default integrations are added.
 
+=head3 debug
+
+Enables debug printing.
+
 =head2 add_breadcrumb
 
   Sentry::SDK->add_breadcrumb({
